@@ -1,9 +1,9 @@
 package Text::ANSITable;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-08'; # DATE
+our $DATE = '2021-08-09'; # DATE
 our $DIST = 'Text-ANSITable'; # DIST
-our $VERSION = '0.603'; # VERSION
+our $VERSION = '0.604'; # VERSION
 
 use 5.010001;
 use Carp;
@@ -16,6 +16,48 @@ use ColorThemeUtil::ANSI qw(item_color_to_ansi);
 use Scalar::Util 'looks_like_number';
 require Win32::Console::ANSI if $^O =~ /Win/;
 
+# see Module::Features for more details on this
+our %FEATURES = (
+    set_v => {
+        TextTable => 1,
+    },
+
+    features => {
+        TextTable => {
+            can_align_cell_containing_wide_character => 1,
+            can_align_cell_containing_color_code     => 1,
+            can_align_cell_containing_newline        => 1,
+            can_use_box_character                    => 1,
+            can_customize_border                     => 1,
+            can_halign                               => 1,
+            can_halign_individual_row                => 1,
+            can_halign_individual_column             => 1,
+            can_halign_individual_cell               => 1,
+            can_valign                               => 1,
+            can_valign_individual_row                => 1,
+            can_valign_individual_column             => 1,
+            can_valign_individual_cell               => 1,
+            can_rowspan                              => 0,
+            can_colspan                              => 0,
+            can_color                                => 1,
+            can_color_theme                          => 1,
+            can_set_cell_height                      => 1,
+            can_set_cell_height_of_individual_row    => 1,
+            can_set_cell_width                       => 1,
+            can_set_cell_width_of_individual_column  => 1,
+            speed                                    => 'slow',
+            can_hpad                                 => 1,
+            can_hpad_individual_row                  => 1,
+            can_hpad_individual_column               => 1,
+            can_hpad_individual_cell                 => 1,
+            can_vpad                                 => 1,
+            can_vpad_individual_row                  => 1,
+            can_vpad_individual_column               => 1,
+            can_vpad_individual_cell                 => 1,
+        },
+    },
+);
+
 my $ATTRS = [qw(
 
                   use_color color_depth use_box_chars use_utf8 columns rows
@@ -1720,7 +1762,7 @@ Text::ANSITable - Create nice formatted tables using extended ASCII and ANSI col
 
 =head1 VERSION
 
-This document describes version 0.603 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2021-08-08.
+This document describes version 0.604 of Text::ANSITable (from Perl distribution Text-ANSITable), released on 2021-08-09.
 
 =head1 SYNOPSIS
 
@@ -1795,6 +1837,190 @@ fine-grained options to customize appearance.
 
 =end HTML
 
+=head1 DECLARED FEATURES
+
+Features declared by this module:
+
+=head2 From feature set TextTable
+
+Features from feature set L<TextTable|Module::Features::TextTable> declared by this module:
+
+=over
+
+=item * can_align_cell_containing_color_code
+
+Value: yes.
+
+=item * can_align_cell_containing_newline
+
+Value: yes.
+
+=item * can_align_cell_containing_wide_character
+
+Value: yes.
+
+=item * can_color
+
+Can produce colored table.
+
+Value: yes.
+
+=item * can_color_theme
+
+Allow choosing colors from a named set of palettes.
+
+Value: yes.
+
+=item * can_colspan
+
+Value: no.
+
+=item * can_customize_border
+
+Let user customize border character in some way, e.g. selecting from several available borders, disable border.
+
+Value: yes.
+
+=item * can_halign
+
+Provide a way for user to specify horizontal alignment (leftE<sol>middleE<sol>right) of cells.
+
+Value: yes.
+
+=item * can_halign_individual_cell
+
+Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual cells.
+
+Value: yes.
+
+=item * can_halign_individual_column
+
+Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual columns.
+
+Value: yes.
+
+=item * can_halign_individual_row
+
+Provide a way for user to specify different horizontal alignment (leftE<sol>middleE<sol>right) for individual rows.
+
+Value: yes.
+
+=item * can_hpad
+
+Provide a way for user to specify horizontal padding of cells.
+
+Value: yes.
+
+=item * can_hpad_individual_cell
+
+Provide a way for user to specify different horizontal padding of individual cells.
+
+Value: yes.
+
+=item * can_hpad_individual_column
+
+Provide a way for user to specify different horizontal padding of individual columns.
+
+Value: yes.
+
+=item * can_hpad_individual_row
+
+Provide a way for user to specify different horizontal padding of individual rows.
+
+Value: yes.
+
+=item * can_rowspan
+
+Value: no.
+
+=item * can_set_cell_height
+
+Allow setting height of rows.
+
+Value: yes.
+
+=item * can_set_cell_height_of_individual_row
+
+Allow setting height of individual rows.
+
+Value: yes.
+
+=item * can_set_cell_width
+
+Allow setting height of rows.
+
+Value: yes.
+
+=item * can_set_cell_width_of_individual_column
+
+Allow setting height of individual rows.
+
+Value: yes.
+
+=item * can_use_box_character
+
+Can use terminal box-drawing character when drawing border.
+
+Value: yes.
+
+=item * can_valign
+
+Provide a way for user to specify vertical alignment (topE<sol>middleE<sol>bottom) of cells.
+
+Value: yes.
+
+=item * can_valign_individual_cell
+
+Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual cells.
+
+Value: yes.
+
+=item * can_valign_individual_column
+
+Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual columns.
+
+Value: yes.
+
+=item * can_valign_individual_row
+
+Provide a way for user to specify different vertical alignment (topE<sol>middleE<sol>bottom) for individual rows.
+
+Value: yes.
+
+=item * can_vpad
+
+Provide a way for user to specify vertical padding of cells.
+
+Value: yes.
+
+=item * can_vpad_individual_cell
+
+Provide a way for user to specify different vertical padding of individual cells.
+
+Value: yes.
+
+=item * can_vpad_individual_column
+
+Provide a way for user to specify different vertical padding of individual columns.
+
+Value: yes.
+
+=item * can_vpad_individual_row
+
+Provide a way for user to specify different vertical padding of individual rows.
+
+Value: yes.
+
+=item * speed
+
+Subjective speed rating, relative to other text table modules.
+
+Value: "slow".
+
+=back
+
+For more details on module features, see L<Module::Features>.
+
 =head1 REFERRING TO COLUMNS
 
 Columns can be referred to be integer number (0-based) or name (string). You
@@ -3060,7 +3286,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Mario Zieschang Steven Haryanto
+=for stopwords Mario Zieschang Steven Haryanto (on PC)
 
 =over 4
 
@@ -3070,7 +3296,7 @@ Mario Zieschang <mario@zieschang.info>
 
 =item *
 
-Steven Haryanto <sharyanto@cpan.org>
+Steven Haryanto (on PC) <stevenharyanto@gmail.com>
 
 =back
 
